@@ -1,23 +1,26 @@
+# Suppress cli output during testing
+options(cli.default_handler = function(...) { })
 
 # Mock up metacore data
+starwars_short <- dplyr::starwars %>% select(1:5)
 var_spec <- tibble::tibble(
-   variable = names(iris),
+   variable = names(starwars_short),
    length = rep(1, 5),
-   label = c("Sepal Length", "Sepal Width", "Petal Length", "Petal Width", "Species"),
-   type = c("float", "float", "float", "float", "text"),
+   label = c("Name", "Height", "Mass", "Hair Color", "Skin Color"),
+   type = c("text", "int", "int", "int", "text"),
    format = rep(NA_character_, 5),
    common = rep(FALSE, 5)
 )
 
 ds_spec <- tibble::tibble(
-   dataset = "Iris",
+   dataset = "Starwars",
    structure = c(""),
-   label = "Iris"
+   label = "Star Wars"
 )
 
 ds_vars <- tibble::tibble(
-   dataset = rep("Iris", 5),
-   variable = names(iris),
+   dataset = rep("Starwars", 5),
+   variable = names(starwars_short),
    order = 1:5,
    keep = rep(TRUE, 5),
    key_seq = 1:5,
@@ -28,11 +31,12 @@ ds_vars <- tibble::tibble(
 value_spec <- tibble::tibble(
    dataset = character(0),
    variable = character(0),
-   origin = character(0),
    type = character(0),
+   origin = character(0),
+   sig_dig = character(0),
    code_id = character(0),
-   derivation_id = character(0),
-   where = character(0)
+   where = character(0),
+   derivation_id = character(0)
 )
 
 derivations <- tibble::tibble(
@@ -45,14 +49,14 @@ code_id <- tibble::tibble(
    name = character(0),
    type = character(0),
    codes = list()
-   )
+)
 
 # This is loud and I don't want it - just need the metacore object
 mc <- suppressWarnings(
    suppressMessages(
       metacore::metacore(ds_spec, ds_vars, var_spec, value_spec, derivations, code_id)
-      )
    )
+)
 
 test_that("Check that add_labels applies labels properly", {
    x <- mtcars %>%
@@ -77,7 +81,7 @@ test_that("set_variable_labels applies labels properly", {
    # Load in the metacore test object and example data
    suppressMessages(
       mc <- metacore::spec_to_metacore(metacore::metacore_example("p21_mock.xlsx"), quiet=TRUE) %>%
-         metacore::select_dataset("DM")
+         metacore::select_dataset("DM", quiet = TRUE)
    )
    dm <- haven::read_xpt(metatools_example("dm.xpt"))
 
@@ -92,31 +96,32 @@ test_that("set_variable_labels applies labels properly", {
 })
 
 test_that("set_variable_labels raises warnings properly", {
-   # This is metadata for the Iris dataset
+   # This is metadata for the dplyr::starwars dataset
    mc <- suppressWarnings(
       suppressMessages(
          metacore::metacore(ds_spec, ds_vars, var_spec, value_spec, derivations, code_id)
       )
-   )
+   ) %>% select_dataset("Starwars", quiet = TRUE)
 
-   iris2 <- iris
-   iris2$new_var <- ""
+   starwars_short2 <- starwars_short
+   starwars_short2$new_var <- ""
 
-   expect_warning(set_variable_labels(iris2, mc))
+   # Variables in data not in metadata
+   expect_warning(set_variable_labels(starwars_short2, mc))
 
    mc <- suppressWarnings(
       suppressMessages(
-         metacore::metacore(ds_spec, ds_vars, var_spec[1:4, ], value_spec, derivations, code_id)
+         metacore::metacore(ds_spec, ds_vars[1:4, ], var_spec[1:4, ], value_spec, derivations, code_id) %>%
+            metacore::select_dataset("Starwars", quiet = TRUE)
       )
    )
-
-   expect_warning(set_variable_labels(iris, mc))
+   expect_warning(set_variable_labels(starwars_short, mc))
 
 })
 
 test_that("removal_labels works to remvoe all labels", {
    data <- tibble::tibble(a = 1:5,
-          b = letters[1:5])
+                          b = letters[1:5])
    data_lab <- data %>%
       purrr::map2_dfr(c("apple", "pear"), function(x, y ){
          attr(x, "label") <- y
