@@ -1,3 +1,6 @@
+# Suppress cli output during testing
+options(cli.default_handler = function(...) { })
+
 test_that("metatools_example", {
   expect_equal(metatools_example(), c("adsl.xpt", "dm.xpt"))
   expect_equal(
@@ -13,8 +16,6 @@ test_that("metatools_example", {
 
 test_that("make_lone_dataset", {
    load(metacore::metacore_example("pilot_ADaM.rda"))
-   expect_error(make_lone_dataset(metacore, NULL), "Requires either a subsetted metacore object or a dataset name")
-
-   ds_spec <- make_lone_dataset(metacore, "ADSL")$ds_spec
-   expect_equal(nrow(ds_spec), 1)
+   # Test deprecated function. Deprecated warning suppressed.
+   suppressWarnings(expect_error(make_lone_dataset(metacore, NULL)))
 })
